Welcome to PyPAGO’s documentation! — PyPAGO 1.0.1 documentation

# Welcome to PyPAGO’s documentation!

This document describes the Python version of the “Physical Analysis of Gridded Ocean” (PyPAGO hereafter) set of MATLAB programs available at http://www.whoi.edu/science/PO/pago/. This set of programs aims at comparing multiple fields (such as temperature, salinity and velocity) of gridded ocean models along pre-defined sections.

The main difference between the Python and MATLAB versions are:

- Graphical User Interface (GUI) that has been developed, in order to make it more user-friendly (see Section 2.2.2 and Section 2.3.2)
- An easy way to define closed domains from gridded sections (see Section 2.4.2), hence allowing the computation of closed budgets (heat budgets for instance, see Section 2.7.2) )
- The possibility to extract as many variables as you want, for instance, biogeochemical variables (see Section 2.5)

If you find a bug or want to contribute, please contact us at pago-dev@groupes.renater.fr

> Contents:

> - 1. Introduction
>   - 1.1. Requirements
>   - 1.2. Installation
> - 2. User manual
>   - 2.1. Parameter file
>   - 2.2. Definition of section longitude/latitude endpoints
>   - 2.3. Create gridded sections
>   - 2.4. Definition of domains
>   - 2.5. Loading model data outputs
>   - 2.6. Plotting
>   - 2.7. Scientific diagnostics
> - 3. API reference
>   - 3.1. Classes
>   - 3.2. Processing model grid
>   - 3.3. Input/Output
>   - 3.4. NetCDF conversion
>   - 3.5. Loading data
>   - 3.6. Miscellaneous
>   - 3.7. Scientific calculations
>   - 3.8. Plotting
> - 4. Bibliography

# Indices and tables

- Index
- Module Index
- Search Page